# fiat ticker names
BITCOIN = 'btc'
ETHEREUM = 'eth'
USDT = 'usdt'
LTC = 'ltc'
DASH = 'dash'
ZCASH = 'zec'

FIATS = [
    USDT,
    BITCOIN,
    ETHEREUM,
    LTC,
    DASH,
    ZCASH,
]

# character that splits currency pairs. "fiat<split>currency"
SPLIT_CHARACTER = '_'

# supported exchanges
BITTREX = 'bittrex'
GDAX = 'gdax'
LIQUI = 'liqui'
POLONIEX = 'poloniex'